<?php

  /*

   HtPasswd File Reader with Abilities

   -- Copyright --
   Copyright 2004, by James McDuffie (ttq3sxl02@sneakemail.com)
   Portions (C) 2005, by Roman Mamedov (http://rm.pp.ru/?en.contact)
   
   -- License --
   GNU GPL

   -- Description --

   This class implements reading of a .htpasswd file. It simply reads in
   three field from the file separated by the ':' character:
      username:password:abilities
   The password is encrypted in the usual Apache htpasswd file way. The
   abilites are a comma separated list of actions the user can perform.
   
   -- Example Usage --

   $ht_obj = new HtPasswd('/tmp/.htpasswd');
   $fred_password = $ht_obj->GetUserPassword('fred');
   $fred_can_read = $ht_obj->UserHasAbility('fred', 'read');
   
   -- Change log --
   
   v0.3 -- 26.02.2005 -- RM
   * fixed a couple of bugs

   v0.2 -- 25.02.2005 -- RM
   * $pwd_file_contents are now loaded with file() instead of
     file_get_contents(), so it also works on PHP older than 4.3
   * $abilities_str is now trim()'med, so it works correctly with
     htpasswd which has windows newlines
   * greatly simplified UserHasAbility(), without hurting
     its functionality

  */

define(HTPASSWD_CLASS, '0.2');

Class HtPasswd {

  # user_passwords - An array hash where the key is the username and value 
  # the password
  #
  # user_abilites - An array hash where the key is the username and the value
  # is an array of ability strings
  var $user_passwords = array();
  var $user_abilities = array();

  function HtPasswd($htpasswd_file) {

    if(!file_exists($htpasswd_file)) {
      trigger_error("userauth htpasswd file does not exist!");
    }

    @$pwd_file_contents = file($htpasswd_file);

    foreach($pwd_file_contents as $file_line) {
      # Skip empty lines
      if($file_line != "") {

	list($username, $password, $abilities_str) =
	  preg_split("/\s*:\s*/", $file_line);
	@$abilities = preg_split("/\s*,\s*/", trim($abilities_str));

	$this->user_passwords[$username] = $password;
	$this->user_abilities[$username] = $abilities;
      }
    }

  }
	
  function UserHasAbility($username, $ability) {
    return @in_array($ability, $this->user_abilities[$username]);
  }

  function GetUserPassword($username) {
    return $this->user_passwords[$username];
  }

  function GetAllUsers() {
    return array_keys($this->user_abilities);
  }

}

?>
